Exception: DIDKit::DIDError
- Inherits:
-
StandardError
- Object
- StandardError
- DIDKit::DIDError
- Defined in:
- lib/didkit/errors.rb
Overview
Raised when a string is not a valid DID or not of the right type.
Raised when a string is not a valid DID or not of the right type.